@@ -57,7 +57,8 @@ group.mean <- function(x, ina,ina.max = max(ina)) {
 #[export]
 group<-function(x,ina,method="sum",ina.min=NULL,ina.max = NULL,ina.length.unique=NULL,mad.method="median") {
 	if(method=="med"){
-		ina.max<- if(is.null(ina.length.unique)) length(unique(ina)) else ina.length.unique
+		ina.max<- if(is.null(ina.max)) max(ina) 
+		ina.min<- if(is.null(ina.length.unique)) length(unique(ina))
 	}
 	.Call(Rfast_group,x,ina,method,ina.min,ina.max,mad.method)
 }
\ No newline at end of file
