@@ -40,7 +40,7 @@ BEGIN_RCPP
     RNGScope __rngScope;
     traits::input_parameter< NumericMatrix >::type x(xSEXP);
     traits::input_parameter< NumericMatrix >::type y(ySEXP);
-    __result = wrap(dcor(x,y));
+    __result = dcor(x,y);
     return __result;
 END_RCPP
 }
@@ -110,7 +110,7 @@ END_RCPP
 double edist(NumericMatrix x,NumericMatrix y){
 	const int n1=x.ncol(),n2=y.ncol();
 	double mij=total_dista(x, y,false),mii=total_euclidean_dist(x,false),mjj=total_euclidean_dist(y,false);
-	return (2 * mij - n2 * mii / n1 - n1 * mjj/n2 ) / (n1 + n2);
+        return (2 * mij/(n1 * n2) - 2 * mii/(n1*n1) - 2 * mjj/(n2*n2) ) * n1 * n2 / (n1 + n2);
 }
 
 RcppExport SEXP Rfast_edist(SEXP xSEXP,SEXP ySEXP) {
