@@ -1,8 +1,7 @@
 //Author: Manos Papadakis
 
-// [[Rcpp::depends(RcppArmadillo)]]
 #include <RcppArmadillo.h>
-#include "templates.h"
+#include "Rfast.h"
 
 using namespace arma;
 using namespace Rcpp;
@@ -23,8 +22,8 @@ double trigamma(double);
 void i4mat_floyd(int, NumericVector &);
 void i4mat_floyd_with_paths(const int, NumericVector&,NumericVector&);
 rowvec colMedians(mat);
-void combn(NumericVector&,const int,const int, vector<double>&,
-       NumericMatrix&,int&);
+void combn(arma::vec& vals, const int n, const unsigned int start_idx, 
+		std::vector<double>& combn_data, double*& combn_col);
 int my_round(const double);
 double my_round_gen_na_rm(double,const int&);
 double my_round_gen_simple(double,const int&);
@@ -40,13 +39,11 @@ bool my_any(int* ,int *);
 double total_dista(NumericMatrix, NumericMatrix,const bool);
 colvec pnormc(colvec);
 double sum_abs(mat,mat);
-NumericVector toNumbers(string,char);
+NumericVector toNumbers(string,const string);
 IntegerVector combine(IntegerVector,IntegerVector);
 double total_euclidean_dist(NumericMatrix,const bool);
 NumericMatrix euclidean_dist(NumericMatrix,const bool);
 icolvec get_k_indices(rowvec,const int&);
-SEXP eachrow_min_abs(SEXP,SEXP);
-SEXP eachcol_min_abs(SEXP,SEXP);
 IntegerVector Order(NumericVector,const bool,const bool);
 NumericVector Rank(NumericVector,string,const bool,const bool);
 double calcDevRes(colvec,colvec,colvec);
